@@ -809,7 +809,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+                [utils.get_data_files_path("ansible", "seed-manage-containers.yml")],  # noqa
                 extra_vars={'kayobe_action': 'deploy'}
             ),
             mock.call(
@@ -863,7 +863,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+                [utils.get_data_files_path("ansible", "seed-manage-containers.yml")],  # noqa
                 extra_vars={'kayobe_action': 'deploy'}
             ),
             mock.call(
@@ -1450,7 +1450,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                "mariadb_backup",
+                "mariadb-backup",
                 extra_args=[]
             ),
         ]
@@ -1482,7 +1482,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                "mariadb_backup",
+                "mariadb-backup",
                 extra_args=["--incremental"]
             ),
         ]
@@ -1522,7 +1522,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                "mariadb_recovery",
+                "mariadb-recovery",
                 extra_vars={}
             ),
         ]
@@ -1563,7 +1563,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                "mariadb_recovery",
+                "mariadb-recovery",
                 extra_vars={
                     "mariadb_recover_inventory_name": "foo"
                 }
@@ -1708,7 +1708,7 @@ class TestCase(unittest.TestCase):
             ),
             mock.call(
                 mock.ANY,
-                "deploy-containers",
+                "manage-containers",
             ),
         ]
         self.assertListEqual(expected_calls, mock_kolla_run.call_args_list)
